@@ -33,7 +33,11 @@ def runBB(train=True, predict=False):
     if predict:
         predict_path = 'predict_images'
 
-    
+
+    # trying to predict without training or selecting an existing network
+    if dt_string is None and not train and predict:
+        print('Selected folder ('+file_path+') does not contain network weights to use for prediction.')
+        return
 
 
     BBHP(file_path,param,predict_path=predict_path,dt_string=dt_string)
